// Peer-to-Peer Protocol Template

const peerToPeerTemplate = {
  id: "peer-to-peer",
  title: "Peer-to-Peer",
  description: "A self-facilitated process where participants work together directly to resolve disputes",
  data: {
    stages: {
      intake: {
        process_start: {
          processStartText: "The dispute process begins when a community member fills out an incident report form. This form includes details about the parties involved in the dispute, a description of what happened, including dates and times, any relevant evidence or documentation, and a description of the outcome the person is seeking. The form can be submitted electronically through our community portal or as a paper form to the designated community coordinator."
        },
        rules_access: {
          rulesAccessText: "Community rules are kept in a shared digital repository accessible to all members, with physical copies posted in community spaces. Rules are reviewed annually in a community-wide meeting."
        },
        information_access: {
          informationAccessText: "Information about disputes is shared only with those directly involved in the process. A summary of resolved disputes (with identifying details removed) is shared quarterly to help the community learn and improve processes."
        },
        participant_inclusion: {
          participantInclusionText: "When a dispute is filed, all identified parties are contacted via their preferred communication method within 48 hours. They receive a copy of the dispute form and information about the peer-to-peer resolution process."
        },
        participation_requirement: {
          participationRequirementText: "Participation is voluntary but strongly encouraged. Community members have agreed in advance that the peer resolution process is the first step before escalating disputes to other forums."
        },
        participation_commitments: {
          participationCommitmentsText: "Participants commit to: 1) Communicating honestly and respectfully, 2) Listening to understand rather than to respond, 3) Working toward a mutually beneficial resolution, 4) Respecting confidentiality, and 5) Following through on any agreed-upon actions."
        },
        context: {
          contextText: "To support effective peer-to-peer resolution, consider these resources:\n\n1. [Communication Guide](https://example.com/communication) - Effective communication techniques for difficult conversations\n2. [Conflict Resolution Basics](https://example.com/basics) - Fundamental concepts for resolving disputes\n3. [Active Listening Tutorial](https://example.com/listening) - How to listen effectively during conflict\n4. [Interest-Based Negotiation](https://example.com/negotiation) - Finding solutions that address underlying interests\n5. [Agreement Writing Templates](https://example.com/agreements) - Templates for documenting your resolutions"
        }
      },
      process: {
        preparation: {
          preparationText: "Both parties have 3-5 days to prepare for the conversation. During this time, they reflect on the issue, their needs, and possible solutions. A preparation worksheet is provided to help structure their thoughts. Participants may seek advice from trusted friends but are asked to keep details confidential."
        },
        place: {
          placeText: "Participants choose a neutral location that feels comfortable for both parties. This could be a community meeting room, quiet outdoor space, or online video call if necessary. The space should be private, quiet, and free from interruptions."
        },
        facilitation: {
          facilitationText: "This process is self-facilitated by the participants. Both parties review a shared guidance document on productive communication before meeting. This document includes suggested time frames, communication techniques, and a basic structure for the conversation."
        },
        communication: {
          communicationText: "Participants follow these guidelines: 1) Take turns speaking without interruption, 2) Use 'I' statements to express feelings and needs, 3) Ask clarifying questions, 4) Summarize what you've heard to ensure understanding, 5) Focus on the present issue and future solutions rather than past grievances."
        },
        participation: {
          participationText: "Only the directly involved parties participate in the initial conversation. If they reach an impasse, they may jointly decide to invite a mutual trusted friend to help facilitate a follow-up conversation."
        },
        documentation: {
          documentationText: "Participants take collaborative notes during the meeting, focusing on agreements made and next steps. Both parties review these notes at the end of the meeting and receive a copy. These notes remain confidential to the participants."
        }
      },
      assessment: {
        situation: {
          situationText: "Participants assess the situation together by identifying: 1) The specific issue or behavior causing concern, 2) The impact on each person and the community, 3) Related community values or agreements, and 4) What needs to happen for resolution."
        },
        stage_of_conflict: {
          stageOfConflictText: "Participants jointly determine whether the dispute is: 1) Early stage (single incident or misunderstanding), 2) Developing (pattern forming but communication still possible), or 3) Escalated (significant breakdown in communication or trust). This helps determine appropriate next steps."
        },
        needs: {
          needsText: "Each participant identifies and shares their underlying needs, such as respect, clarity, security, fairness, autonomy, or community connection. They discuss how these needs can be addressed while honoring the needs of others."
        },
        evidence: {
          evidenceText: "Participants share relevant information with each other directly. This may include communications, photos, witness accounts, or other documentation. Both parties agree to honestly present all relevant information."
        },
        jurisdiction: {
          jurisdictionText: "The peer-to-peer process is appropriate for most interpersonal conflicts and minor disagreements. If the dispute involves illegal activity, poses safety risks, or requires specialized expertise, participants should refer to the delegation process."
        },
        delegation_options: {
          delegationOptionsText: "Delegation to a different process is appropriate if: 1) The peer-to-peer process has been attempted without resolution, 2) The dispute involves serious safety concerns, 3) There is a significant power imbalance between participants, 4) The issue affects the broader community, or 5) Specialized expertise is needed. If delegation is needed, participants document what has been tried and what issues remain unresolved. They then request assistance from the community mediator pool, a group of trained volunteer mediators who can facilitate a more structured process. These mediators also maintain referral relationships with professional mediators, counselors, and legal services as needed."
        }
      },
      deliberation: {
        information_gathering: {
          informationGatheringText: "Participants ask each other clarifying questions to ensure they fully understand the situation. They may take a break to gather more information if needed before continuing the conversation."
        },
        brainstorming: {
          brainstormingText: "Participants jointly brainstorm potential solutions without immediately evaluating them. All ideas are recorded. After generating options, they discuss the advantages and challenges of each approach."
        },
        discussion: {
          discussionText: "Discussion follows the format of: 1) Each person shares their perspective uninterrupted, 2) Clarifying questions are asked, 3) Areas of agreement and difference are identified, 4) Participants work to find solutions that address core needs of all involved."
        },
        deliberation_format: {
          deliberationFormatText: "The deliberation is a face-to-face conversation (or video call if necessary) that typically lasts 60-90 minutes. If more time is needed, participants may schedule follow-up conversations rather than rushing to resolution."
        }
      },
      resolution: {
        decision_making: {
          decisionMakingText: "Decisions are made through mutual agreement. Both participants must consent to the resolution, meaning they can live with the decision even if it isn't their ideal outcome."
        },
        outcomes: {
          outcomesText: "Possible outcomes include: 1) Clarification of misunderstandings, 2) Apologies and acknowledgment of impact, 3) Agreements about future behavior, 4) Specific actions to restore harm, 5) Plans for ongoing communication, or 6) Agreement to disagree respectfully on certain matters."
        },
        agreement: {
          agreementText: "Agreements are documented in writing, with copies provided to both participants. They include specific, measurable actions with timelines and how progress will be reviewed. Both participants sign the agreement."
        },
        follow_up: {
          followUpText: "Participants schedule a follow-up check-in 2-4 weeks after the agreement to discuss progress and any adjustments needed. This can be a brief meeting or exchange of messages."
        },
        announcement: {
          announcementText: "The resolution remains confidential between the participants unless they jointly agree to share specific information with the wider community."
        }
      },
      appeal: {
        criteria: {
          criteriaText: "If either participant feels the agreement isn't working or circumstances have changed significantly, they can request a follow-up conversation using the same peer-to-peer process."
        },
        appeal_process: {
          appealProcessText: "To revisit the agreement, the participant sends a written request to the other party explaining why they believe the agreement needs adjustment. They then schedule a new conversation following the same format as the original process."
        },
        appeal_deliberation: {
          appealDeliberationText: "The follow-up conversation focuses specifically on the aspects of the agreement that aren't working, rather than reopening the entire dispute. Both parties discuss changes that could make the agreement more effective."
        },
        appeal_resolution: {
          appealResolutionText: "The participants revise their written agreement based on the follow-up conversation, with both signing the updated document."
        }
      }
    }
  }
};

// Export the template
export default peerToPeerTemplate;