// Shalish Mediation Template

const shalishMediationTemplate = {
  id: "shalish-mediation",
  title: "Shalish Mediation",
  description: "A process based on the traditional shalish process for village-level mediation in Bangladesh, with modernizing improvements",
  data: {
    stages: {
      intake: {
        process_start: {
          processStartText: "One or more disputant parties ask a third-party intervenor to assist in the dispute resolution process. If only one of the parties initiates the process, the other party/parties may or may not choose to participate. In the case of the latter, the mediator may require conflicting parties to submit to the mediation process. The mediator may need to educate one or more parties about the benefits of mediation for conflict resolution. Upon the agreement of all parties to participate, the mediator schedules a meeting time agreeable to all."
        },
        rules_access: {
          rulesAccessText: "The rules and procedures for the Shalish mediation process are documented in a community handbook that explains the cultural tradition and modern adaptations made by the Madaripur Legal Aid Association. This handbook is translated into local languages and made available through community centers, government offices, and through trained mediators."
        },
        information_access: {
          informationAccessText: "Information about specific cases is kept confidential among the participating parties and mediators. Statistical information about types of cases addressed (without identifying details) is collected for program evaluation and improvement. Participants receive copies of any agreements they reach during the process."
        },
        participant_inclusion: {
          participantInclusionText: "When a case is brought to a mediator, they arrange for notification of all relevant parties. This is done through direct communication, either in person or by phone. The mediator explains the process, benefits, and what to expect during the mediation. Extended family members or community representatives may also be included when appropriate."
        },
        participation_requirement: {
          participationRequirementText: "While participation is technically voluntary, there is often significant social expectation to engage in the process when invited. The community-based nature of the process means that refusing to participate can have social consequences. Mediators work to encourage participation by emphasizing benefits and addressing concerns."
        },
        participation_commitments: {
          participationCommitmentsText: "Participants in the Shalish mediation commit to: 1) Attending scheduled mediation sessions, 2) Speaking honestly about the dispute, 3) Listening respectfully to others, 4) Following the ground rules established by the mediator, 5) Working toward a resolution in good faith, and 6) Honoring any agreements reached through the process."
        },
        context: {
          contextText: "The Shalish mediation process has roots in traditional Bangladeshi village dispute resolution practices and has been modernized by organizations like the [Madaripur Legal Aid Association](https://mlaabd.org/). It combines cultural traditions with contemporary mediation practices to provide accessible justice mechanisms at the community level. The process is particularly important in contexts where formal legal systems may be inaccessible due to cost, distance, or complexity."
        }
      },
      process: {
        preparation: {
          preparationText: "Before the mediation session, the mediator decides whether to mediate alone or co-mediate. In the case of co-mediation, the mediators determine each others' responsibilities for different aspects of the process, safety protocols in case of problems between mediators, time schedules, selecting a suitable mediation site, the management of case records, and similar logistical considerations."
        },
        place: {
          placeText: "Mediation sessions typically take place in a neutral community space that is accessible to all parties. This might be a community center, local government office, NGO facility, or other location acceptable to all participants. The space should offer privacy, comfortable seating arranged to facilitate conversation, and a culturally appropriate environment."
        },
        facilitation: {
          facilitationText: "Upon the decision to enter the mediation process from the disputant parties, the mediator decides whether to mediate alone or co-mediate. In the case of co-mediation, the mediators determine each others' responsibilities for the different aspects of the mediation process, safety valves in case of problems between mediators, time schedules, a mediation site, the management of case records, and similar housekeeping aspects. Each party is allowed to make an initial statement. The mediators take notes throughout the entire mediation process. Mediators may choose to meet privately with one or all of the disputant parties. In the end, the mediators help the disputants write an agreement."
        },
        communication: {
          communicationText: "Communication in the mediation follows established ground rules: 1) Speak only for yourself and in the first person, 2) Use language that does not blame or find fault with others, 3) Do not interrupt while another is speaking, 4) Use non-inflammatory words, 5) If stating a complaint, raise it as your own concern and follow it with a constructive suggestion as to how it might be resolved, 6) Attack the problems and concerns at hand; do not attack the other person, 7) Make statements about your interests and needs instead of stating your position, 8) Be respectful to others, 9) Listen to understand what each person is saying without being judgmental about the person or the message."
        },
        participation: {
          participationText: "The mediation involves the disputing parties, the mediators, and sometimes community or family representatives who have a stake in the dispute. The mediator may invite specific individuals who can contribute to understanding the situation or implementing solutions. In some cases, the process may involve the whole community, especially when the dispute affects community resources or relationships."
        },
        documentation: {
          documentationText: "The mediators take notes throughout the entire mediation process to track issues, proposed solutions, and agreements. At the conclusion of a successful mediation, the mediators help the disputants write a formal agreement that clearly states what each party has agreed to do. This agreement is signed by all parties and sometimes witnessed by community representatives. Copies are provided to all participants."
        }
      },
      assessment: {
        situation: {
          situationText: "In issues of credibility, the mediators may share their understanding of the situation with the disputants. The mediators may also seek background information to receive clarity on what actually happened, in which case, common points are sought after to develop a consensual standard. If the parties fail to develop a standard, the mediator continues the mediation process with the hopes of a standard emerging later during the process."
        },
        stage_of_conflict: {
          stageOfConflictText: "The mediator assesses the stage of the conflict, considering factors such as: 1) How long the dispute has been ongoing, 2) Previous attempts at resolution, 3) Level of hostility between parties, 4) Whether the dispute is escalating or de-escalating, and 5) Community impact of the conflict. This assessment helps determine the appropriate approach and level of intervention needed."
        },
        needs: {
          needsText: "The mediator works to identify the underlying needs of all parties, looking beyond stated positions to understand core interests. These might include needs for respect, security, fair treatment, resource access, or community standing. Successful mediation addresses these fundamental needs rather than just superficial demands."
        },
        evidence: {
          evidenceText: "The Shalish process considers various forms of evidence, including personal testimony, witness accounts, community knowledge, and documentation when available. However, the process focuses less on establishing factual truth and more on reaching mutually acceptable understanding and resolution. Hearsay and community knowledge are often considered valid forms of information."
        },
        jurisdiction: {
          jurisdictionText: "The aim of the mediation process is not to render a judgment, and mediators do not advocate for any one of the disputants. However, they may alternate representations between the parties. Mediators also do not act as social workers, therapists, or counselors. And, while mediators may encourage compliance with the law, they do not have the capacity to enforce the law, or even enforce agreements that disputants enter into between themselves."
        },
        delegation_options: {
          delegationOptionsText: "Cases may be referred to formal legal processes when: 1) They involve serious criminal matters, 2) One party refuses to participate in good faith, 3) Power imbalances cannot be adequately addressed within the mediation, 4) The dispute involves legal matters beyond the mediator's expertise, or 5) The mediation process has been attempted without success. In these cases, the mediator may help connect parties with appropriate legal resources or government authorities."
        }
      },
      deliberation: {
        information_gathering: {
          informationGatheringText: "Information gathering happens through direct testimony from the disputing parties and relevant witnesses. The mediator guides this process, ensuring that all perspectives are heard. They hear all information, including hearsay, and encourage disputants to communicate directly with one another to establish the nature of the conflict."
        },
        brainstorming: {
          brainstormingText: "When a resolution cannot be reached easily, the mediator employs various strategies: 1) Breaking the issue down into smaller parts, 2) Asking parties why particular alternatives are not acceptable, 3) Reviewing the disputants' priorities, 4) Suggesting consultation with experts when needed, 5) Encouraging parties to acknowledge each others' perspectives, 6) Asking disputants for ideas on how to resolve the issue, 7) Assessing the impact of different solutions, and 8) Asking more questions about the problem, hidden agendas, feelings, and emotions."
        },
        discussion: {
          discussionText: "Discussion follows these principles: 1) If the disputants agree on what is credible, a mediator should not interject their own view of the conflict, even if it appears to be more sensible, 2) If the disputants disagree on what is credible, each party should be made responsible for spelling out what the differences are, 3) When there continues to be disagreement over what is credible, mediators should check their own perceptions of the situation with what the disputants say actually happened (i.e., they should 'reality test' their perceptions, but they should do so without judging the correctness or incorrectness of the disputants' perceptions)."
        },
        deliberation_format: {
          deliberationFormatText: "The deliberation takes place in a face-to-face discussion format, typically in a circle or around a table. The mediator guides the conversation, ensuring that all parties have an opportunity to speak and be heard. The process may involve multiple sessions if needed, especially for complex disputes. The mediator may also meet privately with individual parties to discuss sensitive issues or help them prepare for joint discussions."
        }
      },
      resolution: {
        decision_making: {
          decisionMakingText: "Resolution emerges through a process of negotiation and consensus-building facilitated by the mediator. The mediator does not impose solutions but helps parties identify mutually acceptable options. Once the disputants begin considering options for resolving their conflict, they enter into 'bargaining and negotiations' that involve a give-and-take on important issues."
        },
        outcomes: {
          outcomesText: "Typical outcomes include: 1) Specific agreements about disputed issues, 2) Commitments to changed behavior in the future, 3) Restitution or compensation for harm or loss, 4) Clarified expectations for future interactions, 5) Repaired relationships between the parties, and 6) Public acknowledgment of the resolution when appropriate."
        },
        agreement: {
          agreementText: "Once the disputants seriously begin considering options for resolving their conflict, they enter into 'bargaining and negotiations.' This stage in the mediation process involves a 'give and take' on issues important to the disputants. Bargaining usually follows a sequential order consisting of proposals, counterproposals, and concessions. The ultimate goal is to find and agree on options that will satisfy the needs of all the conflicting parties."
        },
        follow_up: {
          followUpText: "Follow-up mechanisms include: 1) Scheduled check-ins to verify implementation of agreements, 2) Community monitoring to encourage compliance, 3) Opportunity to reconvene the mediation if implementation challenges arise, 4) Communication channels to address new issues before they escalate, and 5) Verification and celebration of successful resolution when appropriate."
        },
        announcement: {
          announcementText: "Depending on the nature of the dispute, resolutions may be announced publicly in community meetings, especially when they affect community resources or norms. In more private matters, the resolution may remain confidential to the parties involved. The community is often informed that a resolution has been reached even if specific details are not shared."
        }
      },
      appeal: {
        criteria: {
          criteriaText: "If parties are dissatisfied with the mediation outcome or if agreements are not being honored, they may request a follow-up mediation. This is appropriate when: 1) New information has emerged, 2) Circumstances have changed significantly, 3) Agreements have proven unworkable in practice, or 4) One party has failed to fulfill their commitments."
        },
        appeal_process: {
          appealProcessText: "To revisit a mediation, parties contact the original mediator or the coordinating organization. The mediator assesses the situation and may organize a follow-up session with all original participants. In some cases, a different mediator might be assigned if there are concerns about the original process."
        },
        appeal_deliberation: {
          appealDeliberationText: "The follow-up mediation focuses specifically on unresolved issues or implementation challenges. The mediator reviews the original agreement, identifies areas of concern, and facilitates a discussion to address these specific points. The process follows the same principles as the original mediation but with a narrower focus."
        },
        appeal_resolution: {
          appealResolutionText: "The follow-up process results in either a reaffirmation of the original agreement, modifications to address implementation challenges, or in some cases, a completely new agreement. The revised agreement is documented and signed by all parties, replacing or supplementing the original agreement."
        }
      }
    }
  }
};

// Export the template
export default shalishMediationTemplate;